==> peekabot-0.6.0.tar.bz2: peekabot-0.6.0/src/client/proxies/PointCloudProxy.cc <==
/*
 * Copyright Staffan Gimåker 2008-2009.
 *
 * ---
 *
 * Distributed under the Boost Software License, Version 1.0.
 * (See accompanying file LICENSE_1_0.txt or copy at
 * http://www.boost.org/LICENSE_1_0.txt)
 */

#include "PointCloudProxy.hh"
#include "../PeekabotClient.hh"

#include "../../actions/AddPointCloud.hh"
#include "../../actions/AssignPointCloud.hh"


using namespace peekabot;
using namespace peekabot::client;


//
// ------------------ PointCloudProxyBase implementation -------------------
//


PointCloudProxyBase::PointCloudProxyBase()
{
}


PointCloudProxyBase::PointCloudProxyBase(PointCloudProxyBase &p)
    : ObjectProxyBase(p),
      ScalableProxyBase(p),
      VertexBasedProxyBase(p)
{
}


//
// ------------------ PointCloudProxy implementation -------------------
//


PointCloudProxy::PointCloudProxy()
{
}


PointCloudProxy::PointCloudProxy(PointCloudProxyBase &p)
    : ObjectProxyBase(p),
      PointCloudProxyBase(p)
{
}


PointCloudProxy &PointCloudProxy::operator=(const PointCloudProxy &p) throw()
{
    return *this = (PointCloudProxyBase &)p;
}


PointCloudProxy &PointCloudProxy::operator=(const PointCloudProxyBase &p) throw()
{
    unchecked_assign(unchecked_get_client_impl(p), get_pseudonym(p));
    return *this;
}


DelayedDispatch PointCloudProxy::assign(const ObjectProxyBase &p)
{
    unchecked_assign(get_client_impl(p), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AssignPointCloud(PathIdentifier(get_object_id(p)), 
                             get_object_id()));
}


DelayedDispatch PointCloudProxy::assign(
    PeekabotClient &client, const std::string &path)
{
    unchecked_assign(get_client_impl(client), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AssignPointCloud(PathIdentifier(path), get_object_id()));
}


DelayedDispatch PointCloudProxy::assign(
    const ObjectProxyBase &parent, 
    const std::string &rel_path)
{
    unchecked_assign(get_client_impl(parent), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(), new AssignPointCloud(
            PathIdentifier(get_object_id(parent), rel_path), get_object_id()));
}


DelayedDispatch PointCloudProxy::add(
    PeekabotClient &client,
    const std::string &path,
    NameConflictPolicy conflict_policy)
{
    unchecked_assign(get_client_impl(client), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AddPointCloud(PathIdentifier(path), 
                          conflict_policy, true, get_object_id()));
}


DelayedDispatch PointCloudProxy::add(
    const ObjectProxyBase &parent, 
    const std::string &name,
    NameConflictPolicy conflict_policy)
{
    unchecked_assign(get_client_impl(parent), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AddPointCloud(PathIdentifier(get_object_id(parent), name), 
                          conflict_policy, true, get_object_id()));
}

==> peekabot-0.8.4.tar.bz2: peekabot-0.8.4/src/client/proxies/PointCloudProxy.cc <==
/*
 * Copyright Staffan Gimåker 2008-2010.
 *
 * ---
 *
 * Distributed under the Boost Software License, Version 1.0.
 * (See accompanying file LICENSE_1_0.txt or copy at
 * http://www.boost.org/LICENSE_1_0.txt)
 */

#include "PointCloudProxy.hh"
#include "../PeekabotClient.hh"
#include "../../ObjectTypes.hh"

#include "../../actions/AddObject.hh"
#include "../../actions/Assign.hh"


using namespace peekabot;
using namespace peekabot::client;


//
// ------------------ PointCloudProxyBase implementation -------------------
//


PointCloudProxyBase::PointCloudProxyBase()
{
}


PointCloudProxyBase::PointCloudProxyBase(const PointCloudProxyBase &p)
    : ObjectProxyBase(p),
      ScalableProxyBase(p),
      VertexBasedProxyBase(p)
{
}


//
// ------------------ PointCloudProxy implementation -------------------
//


PointCloudProxy::PointCloudProxy()
{
}


PointCloudProxy::PointCloudProxy(const PointCloudProxyBase &p)
    : ObjectProxyBase(p),
      PointCloudProxyBase(p)
{
}


PointCloudProxy &PointCloudProxy::operator=(const PointCloudProxy &p)
{
    return *this = (PointCloudProxyBase &)p;
}


PointCloudProxy &PointCloudProxy::operator=(const PointCloudProxyBase &p)
{
    unchecked_assign(unchecked_get_client_impl(p), get_pseudonym(p));
    return *this;
}


DelayedDispatch PointCloudProxy::assign(const ObjectProxyBase &p)
{
    unchecked_assign(get_client_impl(p), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new Assign(PathIdentifier(get_object_id(p)),
                   get_object_id(), POINT_CLOUD_OBJECT));
}


DelayedDispatch PointCloudProxy::assign(
    PeekabotClient &client, const std::string &path)
{
    unchecked_assign(get_client_impl(client), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new Assign(PathIdentifier(path), get_object_id(), POINT_CLOUD_OBJECT));
}


DelayedDispatch PointCloudProxy::assign(
    const ObjectProxyBase &parent, 
    const std::string &rel_path)
{
    unchecked_assign(get_client_impl(parent), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(), new Assign(
            PathIdentifier(get_object_id(parent), rel_path),
            get_object_id(), POINT_CLOUD_OBJECT));
}


DelayedDispatch PointCloudProxy::add(
    PeekabotClient &client,
    const std::string &path,
    NameConflictPolicy conflict_policy)
{
    unchecked_assign(get_client_impl(client), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AddObject(PathIdentifier(path), conflict_policy,
                      get_object_id(), POINT_CLOUD_OBJECT));
}


DelayedDispatch PointCloudProxy::add(
    const ObjectProxyBase &parent, 
    const std::string &name,
    NameConflictPolicy conflict_policy)
{
    unchecked_assign(get_client_impl(parent), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AddObject(PathIdentifier(get_object_id(parent), name),
                      conflict_policy, get_object_id(), POINT_CLOUD_OBJECT));
}
